==> haskell-gtk2hs-buildtools-0.13.2.2-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.2.2
id: gtk2hs-buildtools-0.13.2.2-DL2kIuo78X3BsS9OH7wBAw
key: gtk2hs-buildtools-0.13.2.2-DL2kIuo78X3BsS9OH7wBAw
license: GPL-2
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
exposed: True
indefinite: False
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
abi: e5c3f498194c12bc96d3d078f4e31c9b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/gtk2hs-buildtools-0.13.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/gtk2hs-buildtools-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.2.2-DL2kIuo78X3BsS9OH7wBAw
depends:
    base-4.10.0.0 process-1.6.1.0 array-0.5.2.0 pretty-1.1.3.3
    filepath-1.4.1.2 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK Cabal-2.0.0.2
    directory-1.3.0.2 containers-0.5.10.2
    hashtables-1.2.1.1-5Oaw7XKpRCC6AVfg0GekD
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             array-0.5.2.0=044554210403f250e868a2183de060a9
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             Cabal-2.0.0.2=a2520fd25489686ee7e9d64a6ce11828
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             hashtables-1.2.1.1-5Oaw7XKpRCC6AVfg0GekD=2f4094fde279bb9ee18db79cbf66da66
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.2.2-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.2.2
id: gtk2hs-buildtools-0.13.2.2-2I7h9MxqXqa1uKAGH0bymP
key: gtk2hs-buildtools-0.13.2.2-2I7h9MxqXqa1uKAGH0bymP
license: GPL-2
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
exposed: True
indefinite: False
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
abi: b694a41a8a5ef165a8a3fa8b9b25e23e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/gtk2hs-buildtools-0.13.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/gtk2hs-buildtools-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.2.2-2I7h9MxqXqa1uKAGH0bymP
depends:
    base-4.10.0.0 process-1.6.1.0 array-0.5.2.0 pretty-1.1.3.3
    filepath-1.4.1.2 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK Cabal-2.0.0.2
    directory-1.3.0.2 containers-0.5.10.2
    hashtables-1.2.2.0-DWDZhHGT75K8Jt5bmmtiVH
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             array-0.5.2.0=044554210403f250e868a2183de060a9
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             Cabal-2.0.0.2=a2520fd25489686ee7e9d64a6ce11828
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             hashtables-1.2.2.0-DWDZhHGT75K8Jt5bmmtiVH=3eb09822b4a1a7e670c4fc66154a81af
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
